@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,18 +52,20 @@
 
 package org.mariadb.jdbc;
 
-import org.mariadb.jdbc.internal.*;
-import org.mariadb.jdbc.internal.com.send.parameters.*;
-import org.mariadb.jdbc.internal.util.exceptions.*;
-
-import java.io.*;
-import java.math.*;
-import java.net.*;
-import java.sql.Date;
+import java.io.InputStream;
+import java.io.Reader;
+import java.math.BigDecimal;
+import java.math.BigInteger;
+import java.net.URL;
 import java.sql.*;
 import java.time.*;
-import java.time.format.*;
-import java.util.*;
+import java.time.format.DateTimeFormatter;
+import java.time.format.DateTimeFormatterBuilder;
+import java.util.Calendar;
+import java.util.TimeZone;
+import org.mariadb.jdbc.internal.ColumnType;
+import org.mariadb.jdbc.internal.com.send.parameters.*;
+import org.mariadb.jdbc.internal.util.exceptions.ExceptionFactory;
 
 public abstract class BasePrepareStatement extends MariaDbStatement implements PreparedStatement {
 
@@ -94,7 +96,6 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
           .toFormatter();
 
   protected int autoGeneratedKeys;
-  protected boolean hasLongData = false;
   private boolean useFractionalSeconds;
   private boolean noBackslashEscapes;
 
@@ -109,13 +110,15 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
    *     ResultSet.CONCUR_READ_ONLY</code> or <code>ResultSet.CONCUR_UPDATABLE</code>
    * @param autoGeneratedKeys a flag indicating whether auto-generated keys should be returned; one
    *     of <code>Statement.RETURN_GENERATED_KEYS</code> or <code>Statement.NO_GENERATED_KEYS</code>
+   * @param exceptionFactory exception factory
    */
   public BasePrepareStatement(
       MariaDbConnection connection,
       int resultSetScrollType,
       int resultSetConcurrency,
-      int autoGeneratedKeys) {
-    super(connection, resultSetScrollType, resultSetConcurrency);
+      int autoGeneratedKeys,
+      ExceptionFactory exceptionFactory) {
+    super(connection, resultSetScrollType, resultSetConcurrency, exceptionFactory);
     this.noBackslashEscapes = protocol.noBackslashEscapes();
     this.useFractionalSeconds = options.useFractionalSeconds;
     this.autoGeneratedKeys = autoGeneratedKeys;
@@ -169,7 +172,6 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
       return;
     }
     setParameter(parameterIndex, new ReaderParameter(reader, length, noBackslashEscapes));
-    hasLongData = true;
   }
 
   /**
@@ -196,7 +198,6 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
       return;
     }
     setParameter(parameterIndex, new ReaderParameter(reader, length, noBackslashEscapes));
-    hasLongData = true;
   }
 
   /**
@@ -225,7 +226,6 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
       return;
     }
     setParameter(parameterIndex, new ReaderParameter(reader, noBackslashEscapes));
-    hasLongData = true;
   }
 
   /**
@@ -239,7 +239,7 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
    *     PreparedStatement</code>
    */
   public void setRef(final int parameterIndex, final Ref ref) throws SQLException {
-    throw ExceptionMapper.getFeatureNotSupportedException("REF not supported");
+    throw exceptionFactory.notSupported("REF parameter are not supported");
   }
 
   /**
@@ -260,7 +260,6 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
     setParameter(
         parameterIndex,
         new StreamParameter(blob.getBinaryStream(), blob.length(), noBackslashEscapes));
-    hasLongData = true;
   }
 
   /**
@@ -288,7 +287,6 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
       return;
     }
     setParameter(parameterIndex, new StreamParameter(inputStream, length, noBackslashEscapes));
-    hasLongData = true;
   }
 
   /**
@@ -316,7 +314,6 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
     }
 
     setParameter(parameterIndex, new StreamParameter(inputStream, noBackslashEscapes));
-    hasLongData = true;
   }
 
   /**
@@ -338,7 +335,6 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
     setParameter(
         parameterIndex,
         new ReaderParameter(clob.getCharacterStream(), clob.length(), noBackslashEscapes));
-    hasLongData = true;
   }
 
   /**
@@ -396,7 +392,7 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
    *     PreparedStatement</code>
    */
   public void setArray(final int parameterIndex, final Array array) throws SQLException {
-    throw ExceptionMapper.getFeatureNotSupportedException("Arrays not supported");
+    throw exceptionFactory.notSupported("Arrays not supported");
   }
 
   /**
@@ -642,11 +638,11 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
    *     PreparedStatement</code>
    */
   public void setRowId(final int parameterIndex, final RowId rowid) throws SQLException {
-    throw ExceptionMapper.getFeatureNotSupportedException("RowIDs not supported");
+    throw exceptionFactory.notSupported("RowIDs not supported");
   }
 
   /**
-   * Sets the designated paramter to the given <code>String</code> object. The driver converts this
+   * Sets the designated parameter to the given <code>String</code> object. The driver converts this
    * to a SQL <code>NCHAR</code> or <code>NVARCHAR</code> or <code>LONGNVARCHAR</code> value
    * (depending on the argument's size relative to the driver's limits on <code>NVARCHAR</code>
    * values) when it sends it to the database.
@@ -777,7 +773,7 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
    */
   @Override
   public void setSQLXML(final int parameterIndex, final SQLXML xmlObject) throws SQLException {
-    throw ExceptionMapper.getFeatureNotSupportedException("SQlXML not supported");
+    throw exceptionFactory.notSupported("SQlXML not supported");
   }
 
   /**
@@ -907,28 +903,24 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
           parameterIndex,
           new ZonedDateTimeParameter(
               ((OffsetDateTime) obj).toZonedDateTime(),
-              protocol.getTimeZone().toZoneId(),
+              protocol.getTimeZone(),
               useFractionalSeconds,
               options));
     } else if (obj instanceof OffsetTime) {
       setParameter(
           parameterIndex,
           new OffsetTimeParameter(
-              (OffsetTime) obj, protocol.getTimeZone().toZoneId(), useFractionalSeconds, options));
+              (OffsetTime) obj, protocol.getTimeZone(), useFractionalSeconds, options));
     } else if (obj instanceof ZonedDateTime) {
       setParameter(
           parameterIndex,
           new ZonedDateTimeParameter(
-              (ZonedDateTime) obj,
-              protocol.getTimeZone().toZoneId(),
-              useFractionalSeconds,
-              options));
+              (ZonedDateTime) obj, protocol.getTimeZone(), useFractionalSeconds, options));
     } else if (obj instanceof LocalTime) {
       setParameter(parameterIndex, new LocalTimeParameter((LocalTime) obj, useFractionalSeconds));
     } else {
       // fallback to sending serialized object
       setParameter(parameterIndex, new SerializableParameter(obj, noBackslashEscapes));
-      hasLongData = true;
     }
   }
 
@@ -954,18 +946,20 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
       case Types.ROWID:
       case Types.SQLXML:
       case Types.STRUCT:
-        throw ExceptionMapper.getFeatureNotSupportedException("Type not supported");
+        throw exceptionFactory.notSupported("Type not supported");
       default:
         break;
     }
 
     if (obj == null) {
       setNull(parameterIndex, Types.INTEGER);
-    } else if (obj instanceof String) {
+    } else if (obj instanceof String || obj instanceof Character) {
       if (targetSqlType == Types.BLOB) {
-        throw ExceptionMapper.getSqlException("Cannot convert a String to a Blob");
+        throw exceptionFactory.create(
+            String.format(
+                "Cannot convert a %s to a Blob", obj instanceof String ? "string" : "character"));
       }
-      String str = (String) obj;
+      String str = obj instanceof String ? (String) obj : ((Character) obj).toString();
       try {
         switch (targetSqlType) {
           case Types.BIT:
@@ -1019,27 +1013,24 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
             setParameter(
                 parameterIndex,
                 new OffsetTimeParameter(
-                    OffsetTime.parse(str),
-                    protocol.getTimeZone().toZoneId(),
-                    useFractionalSeconds,
-                    options));
+                    OffsetTime.parse(str), protocol.getTimeZone(), useFractionalSeconds, options));
             break;
           case Types.TIMESTAMP_WITH_TIMEZONE:
             setParameter(
                 parameterIndex,
                 new ZonedDateTimeParameter(
                     ZonedDateTime.parse(str, SPEC_ISO_ZONED_DATE_TIME),
-                    protocol.getTimeZone().toZoneId(),
+                    protocol.getTimeZone(),
                     useFractionalSeconds,
                     options));
             break;
           default:
-            throw ExceptionMapper.getSqlException(
-                "Could not convert [" + str + "] to " + targetSqlType);
+            throw exceptionFactory.create(
+                String.format("Could not convert [%s] to %s", str, targetSqlType));
         }
       } catch (IllegalArgumentException e) {
-        throw ExceptionMapper.getSqlException(
-            "Could not convert [" + str + "] to " + targetSqlType, e);
+        throw exceptionFactory.create(
+            String.format("Could not convert [%s] to %s", str, targetSqlType), e);
       }
     } else if (obj instanceof Number) {
       Number bd = (Number) obj;
@@ -1081,8 +1072,8 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
           setString(parameterIndex, bd.toString());
           break;
         default:
-          throw ExceptionMapper.getSqlException(
-              "Could not convert [" + bd + "] to " + targetSqlType);
+          throw exceptionFactory.create(
+              String.format("Could not convert [%s] to %s", bd, targetSqlType));
       }
     } else if (obj instanceof byte[]) {
       if (targetSqlType == Types.BINARY
@@ -1090,7 +1081,7 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
           || targetSqlType == Types.LONGVARBINARY) {
         setBytes(parameterIndex, (byte[]) obj);
       } else {
-        throw ExceptionMapper.getSqlException(
+        throw exceptionFactory.create(
             "Can only convert a byte[] to BINARY, VARBINARY or LONGVARBINARY");
       }
 
@@ -1130,30 +1121,26 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
           parameterIndex,
           new ZonedDateTimeParameter(
               ((OffsetDateTime) obj).toZonedDateTime(),
-              protocol.getTimeZone().toZoneId(),
+              protocol.getTimeZone(),
               useFractionalSeconds,
               options));
     } else if (obj instanceof OffsetTime) {
       setParameter(
           parameterIndex,
           new OffsetTimeParameter(
-              (OffsetTime) obj, protocol.getTimeZone().toZoneId(), useFractionalSeconds, options));
+              (OffsetTime) obj, protocol.getTimeZone(), useFractionalSeconds, options));
     } else if (obj instanceof ZonedDateTime) {
       setParameter(
           parameterIndex,
           new ZonedDateTimeParameter(
-              (ZonedDateTime) obj,
-              protocol.getTimeZone().toZoneId(),
-              useFractionalSeconds,
-              options));
+              (ZonedDateTime) obj, protocol.getTimeZone(), useFractionalSeconds, options));
     } else if (obj instanceof LocalTime) {
       setParameter(parameterIndex, new LocalTimeParameter((LocalTime) obj, useFractionalSeconds));
     } else {
-      throw ExceptionMapper.getSqlException(
-          "Could not set parameter in setObject, could not convert: "
-              + obj.getClass()
-              + " to "
-              + targetSqlType);
+      throw exceptionFactory.create(
+          String.format(
+              "Could not set parameter in setObject, could not convert: %s to %s",
+              obj.getClass(), targetSqlType));
     }
   }
 
@@ -1181,7 +1168,6 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
       return;
     }
     setParameter(parameterIndex, new StreamParameter(stream, length, noBackslashEscapes));
-    hasLongData = true;
   }
 
   /**
@@ -1213,7 +1199,6 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
       return;
     }
     setParameter(parameterIndex, new StreamParameter(stream, noBackslashEscapes));
-    hasLongData = true;
   }
 
   /**
@@ -1240,7 +1225,6 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
       return;
     }
     setParameter(parameterIndex, new StreamParameter(stream, length, noBackslashEscapes));
-    hasLongData = true;
   }
 
   /**
@@ -1266,7 +1250,6 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
       return;
     }
     setParameter(parameterIndex, new StreamParameter(stream, length, noBackslashEscapes));
-    hasLongData = true;
   }
 
   /**
@@ -1296,7 +1279,6 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
       return;
     }
     setParameter(parameterIndex, new StreamParameter(stream, noBackslashEscapes));
-    hasLongData = true;
   }
 
   /**
@@ -1322,7 +1304,6 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
       return;
     }
     setParameter(parameterIndex, new StreamParameter(stream, length, noBackslashEscapes));
-    hasLongData = true;
   }
 
   /**
@@ -1434,7 +1415,6 @@ public abstract class BasePrepareStatement extends MariaDbStatement implements P
       return;
     }
     setParameter(parameterIndex, new StreamParameter(x, length, noBackslashEscapes));
-    hasLongData = true;
   }
 
   public void setInt(final int column, final int value) throws SQLException {
