@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,8 +52,8 @@
 
 package org.mariadb.jdbc;
 
-import javax.sql.*;
-import javax.transaction.xa.*;
+import javax.sql.XAConnection;
+import javax.transaction.xa.XAResource;
 
 public class MariaXaConnection extends MariaDbPooledConnection implements XAConnection {
 
