@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -89,4 +89,10 @@ public class MariaDbServerCapabilities {
       1L << 32; /* Client support progress indicator (since 10.2) */
   public static final long MARIADB_CLIENT_COM_MULTI =
       1L << 33; /* bundle command during connection */
+
+  /* support of array binding */
+  public static final long MARIADB_CLIENT_STMT_BULK_OPERATIONS = 1L << 34;
+
+  /* support of extended metadata (e.g. type/format information) */
+  public static final long MARIADB_CLIENT_EXTENDED_METADATA = 1L << 35;
 }
