@@ -68,15 +68,9 @@ public class SelectResultSet implements ResultSet {
   public static final int YEAR_IS_DATE_TYPE = 2;
   private static final String NOT_UPDATABLE_ERROR =
       "Updates are not supported when using ResultSet.CONCUR_READ_ONLY";
-  private static final ColumnDefinition[] INSERT_ID_COLUMNS;
 
   private static final int MAX_ARRAY_SIZE = Integer.MAX_VALUE - 8;
 
-  static {
-    INSERT_ID_COLUMNS = new ColumnDefinition[1];
-    INSERT_ID_COLUMNS[0] = ColumnDefinition.create("insert_id", ColumnType.BIGINT);
-  }
-
   protected TimeZone timeZone;
   protected Options options;
   protected ColumnDefinition[] columnsInformation;
@@ -87,7 +81,7 @@ public class SelectResultSet implements ResultSet {
   private boolean isEof;
   private boolean callableResult;
   private MariaDbStatement statement;
-  private RowProtocol row;
+  protected RowProtocol row;
   private int dataFetchTime;
   private boolean streaming;
   private byte[][] data;
@@ -274,6 +268,8 @@ public class SelectResultSet implements ResultSet {
   }
 
   public static SelectResultSet createEmptyResultSet() {
+    ColumnDefinition[] INSERT_ID_COLUMNS = new ColumnDefinition[1];
+    INSERT_ID_COLUMNS[0] = ColumnDefinition.create("insert_id", ColumnType.BIGINT);
     return new SelectResultSet(INSERT_ID_COLUMNS, new ArrayList<>(), null, TYPE_SCROLL_SENSITIVE);
   }
 
@@ -1214,7 +1210,7 @@ public class SelectResultSet implements ResultSet {
       System.arraycopy(row.buf, row.pos, data, 0, row.getLengthMaxFieldSize());
       return (T) data;
 
-    } else if (type.equals(Date.class)) {
+    } else if (type.equals(Date.class) || type.equals(java.util.Date.class)) {
       return (T) row.getInternalDate(col, null, timeZone);
 
     } else if (type.equals(Time.class)) {
@@ -1227,7 +1223,8 @@ public class SelectResultSet implements ResultSet {
       return (T) (Boolean) row.getInternalBoolean(col);
 
     } else if (type.equals(Calendar.class)) {
-      Calendar calendar = Calendar.getInstance(timeZone);
+      Calendar calendar =
+          timeZone == null ? Calendar.getInstance() : Calendar.getInstance(timeZone);
       Timestamp timestamp = row.getInternalTimestamp(col, null, timeZone);
       if (timestamp == null) {
         return null;
