@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,10 +52,9 @@
 
 package org.mariadb.jdbc.internal.com.send.parameters;
 
-import org.mariadb.jdbc.internal.*;
-import org.mariadb.jdbc.internal.io.output.*;
-
-import java.io.*;
+import java.io.IOException;
+import org.mariadb.jdbc.internal.ColumnType;
+import org.mariadb.jdbc.internal.io.output.PacketOutputStream;
 
 public interface ParameterHolder {
 
@@ -72,7 +71,11 @@ public interface ParameterHolder {
 
   void writeBinary(PacketOutputStream pos) throws IOException;
 
-  long getApproximateTextProtocolLength() throws IOException;
+  default void writeLongData(PacketOutputStream pos) throws IOException {
+    return;
+  }
+
+  int getApproximateTextProtocolLength() throws IOException;
 
   String toString();
 
@@ -80,5 +83,5 @@ public interface ParameterHolder {
 
   ColumnType getColumnType();
 
-  boolean isLongData();
+  boolean canBeLongData();
 }
