@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,15 +52,20 @@
 
 package org.mariadb.jdbc.internal.failover;
 
-import org.mariadb.jdbc.*;
-import org.mariadb.jdbc.internal.logging.*;
-import org.mariadb.jdbc.internal.protocol.*;
-import org.mariadb.jdbc.internal.util.dao.*;
-import org.mariadb.jdbc.internal.util.exceptions.*;
-
-import java.lang.reflect.*;
-import java.sql.*;
-import java.util.concurrent.locks.*;
+import java.lang.reflect.InvocationHandler;
+import java.lang.reflect.InvocationTargetException;
+import java.lang.reflect.Method;
+import java.sql.SQLException;
+import java.util.concurrent.locks.ReentrantLock;
+import org.mariadb.jdbc.HostAddress;
+import org.mariadb.jdbc.MariaDbConnection;
+import org.mariadb.jdbc.MariaDbStatement;
+import org.mariadb.jdbc.internal.io.LruTraceCache;
+import org.mariadb.jdbc.internal.logging.Logger;
+import org.mariadb.jdbc.internal.logging.LoggerFactory;
+import org.mariadb.jdbc.internal.protocol.Protocol;
+import org.mariadb.jdbc.internal.util.dao.ServerPrepareResult;
+import org.mariadb.jdbc.internal.util.exceptions.ExceptionFactory;
 
 public class FailoverProxy implements InvocationHandler {
 
@@ -94,6 +99,7 @@ public class FailoverProxy implements InvocationHandler {
 
   private static final Logger logger = LoggerFactory.getLogger(FailoverProxy.class);
   public final ReentrantLock lock;
+  public final LruTraceCache traceCache;
 
   private final Listener listener;
 
@@ -102,12 +108,15 @@ public class FailoverProxy implements InvocationHandler {
    *
    * @param listener failover implementation.
    * @param lock synchronisation lock
+   * @param traceCache trace cache
    * @throws SQLException if connection error occur
    */
-  public FailoverProxy(Listener listener, ReentrantLock lock) throws SQLException {
+  public FailoverProxy(Listener listener, ReentrantLock lock, LruTraceCache traceCache)
+      throws SQLException {
     this.lock = lock;
     this.listener = listener;
     this.listener.setProxy(this);
+    this.traceCache = traceCache;
     this.listener.initializeConnection();
   }
 
@@ -220,14 +229,14 @@ public class FailoverProxy implements InvocationHandler {
           if (!mustBeOnMaster
               && serverPrepareResult.getUnProxiedProtocol().isMasterConnection()
               && !this.listener.hasHostFail()) {
-            // PrepareStatement was to be executed on slave, but since a failover was running on
-            // master connection. Slave connection is up
-            // again, so has to be re-prepared on slave
+            // PrepareStatement was to be executed on replica, but since a failover was running on
+            // master connection. Replica connection is up
+            // again, so has to be re-prepared on replica
             try {
               logger.trace(
-                  "re-prepare query \"{}\" on slave (was " + "temporary on master since failover)",
+                  "re-prepare query \"{}\" on replica (was temporary on master since failover)",
                   serverPrepareResult.getSql());
-              this.listener.rePrepareOnSlave(serverPrepareResult, false);
+              this.listener.rePrepareOnReplica(serverPrepareResult, false);
             } catch (SQLException q) {
               // error during re-prepare, will do executed on master.
             }
@@ -276,7 +285,7 @@ public class FailoverProxy implements InvocationHandler {
           throw e;
         }
       case METHOD_RESET:
-        // listener will report reset on any active connections (Master/slave)
+        // listener will report reset on any active connections (Master/replica)
         listener.reset();
         return null;
       default:
@@ -317,7 +326,7 @@ public class FailoverProxy implements InvocationHandler {
 
           // error is "The MariaDB server is running with the %s option so it cannot execute this
           // statement"
-          // checking that server was master has not been demote to slave without resetting
+          // checking that server was master has not been demote to replica without resetting
           // connections
           if (queryException.getErrorCode() == 1290
               && !isSecondExecution
@@ -412,7 +421,7 @@ public class FailoverProxy implements InvocationHandler {
     try {
       listener.reconnect();
     } catch (SQLException e) {
-      ExceptionMapper.throwException(e, null, null);
+      throw ExceptionFactory.INSTANCE.create(e);
     }
   }
 
