@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -60,6 +60,7 @@ public class TraceObject {
 
   private final boolean send;
   private final int indicatorFlag;
+  private final long threadId;
   private byte[][] buf;
 
   /**
@@ -68,12 +69,14 @@ public class TraceObject {
    * @param send was packet send or received
    * @param indicatorFlag indicator. can be NOT_COMPRESSED, COMPRESSED_PROTOCOL_COMPRESSED_PACKET or
    *     COMPRESSED_PROTOCOL_NOT_COMPRESSED_PACKET
+   * @param threadId current connection thread Id
    * @param buf buffers
    */
-  public TraceObject(boolean send, int indicatorFlag, byte[]... buf) {
+  public TraceObject(boolean send, int indicatorFlag, long threadId, byte[]... buf) {
     this.send = send;
     this.indicatorFlag = indicatorFlag;
     this.buf = buf;
+    this.threadId = threadId;
   }
 
   /** Clear trace array for easy garbage. */
@@ -95,4 +98,8 @@ public class TraceObject {
   public byte[][] getBuf() {
     return buf;
   }
+
+  public long getThreadId() {
+    return threadId;
+  }
 }
