@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,10 +52,10 @@
 
 package org.mariadb.jdbc.internal.io.input;
 
-import org.mariadb.jdbc.internal.com.read.*;
-import org.mariadb.jdbc.internal.io.*;
-
-import java.io.*;
+import java.io.IOException;
+import java.io.InputStream;
+import org.mariadb.jdbc.internal.com.read.Buffer;
+import org.mariadb.jdbc.internal.io.LruTraceCache;
 
 public interface PacketInputStream {
 
@@ -72,4 +72,6 @@ public interface PacketInputStream {
   void setServerThreadId(long serverThreadId, Boolean isMaster);
 
   void setTraceCache(LruTraceCache traceCache);
+
+  InputStream getInputStream();
 }
