@@ -398,6 +398,9 @@ public abstract class AbstractConnectProtocol implements Protocol {
 
   /** Force closes socket and stream readers/writers. */
   public void abort() {
+    if (logger.isDebugEnabled()) {
+      logger.debug("aborting connection {}", serverThreadId);
+    }
     this.explicitClosed = true;
 
     boolean lockStatus = false;
@@ -961,9 +964,6 @@ public abstract class AbstractConnectProtocol implements Protocol {
     StringBuilder sessionOption =
         new StringBuilder("autocommit=").append(options.autocommit ? "1" : "0");
     if ((serverCapabilities & MariaDbServerCapabilities.CLIENT_SESSION_TRACK) != 0) {
-      if (options.trackSchema) {
-        sessionOption.append(", session_track_schema=1");
-      }
       if (options.rewriteBatchedStatements) {
         sessionOption.append(", session_track_system_variables='auto_increment_increment' ");
       }
