@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,25 +52,30 @@
 
 package org.mariadb.jdbc.internal.protocol;
 
-import org.mariadb.jdbc.*;
-import org.mariadb.jdbc.internal.com.read.dao.*;
-import org.mariadb.jdbc.internal.failover.*;
-import org.mariadb.jdbc.internal.failover.impl.*;
-import org.mariadb.jdbc.internal.failover.tools.*;
-import org.mariadb.jdbc.internal.util.pool.*;
+import static org.mariadb.jdbc.internal.util.SqlStates.CONNECTION_EXCEPTION;
 
-import java.net.*;
-import java.sql.*;
+import java.net.SocketException;
+import java.sql.ResultSet;
+import java.sql.SQLException;
 import java.util.*;
-import java.util.concurrent.locks.*;
+import java.util.concurrent.locks.ReentrantLock;
+import org.mariadb.jdbc.HostAddress;
+import org.mariadb.jdbc.UrlParser;
+import org.mariadb.jdbc.internal.com.read.dao.Results;
+import org.mariadb.jdbc.internal.failover.FailoverProxy;
+import org.mariadb.jdbc.internal.failover.impl.AuroraListener;
+import org.mariadb.jdbc.internal.failover.tools.SearchFilter;
+import org.mariadb.jdbc.internal.io.LruTraceCache;
+import org.mariadb.jdbc.internal.util.pool.GlobalStateInfo;
 
-import static org.mariadb.jdbc.internal.util.SqlStates.*;
-
-public class AuroraProtocol extends MastersSlavesProtocol {
+public class AuroraProtocol extends MastersReplicasProtocol {
 
   public AuroraProtocol(
-      final UrlParser url, final GlobalStateInfo globalInfo, final ReentrantLock lock) {
-    super(url, globalInfo, lock);
+      final UrlParser url,
+      final GlobalStateInfo globalInfo,
+      final ReentrantLock lock,
+      LruTraceCache traceCache) {
+    super(url, globalInfo, lock, traceCache);
   }
 
   /**
@@ -192,7 +197,7 @@ public class AuroraProtocol extends MastersSlavesProtocol {
 
         } else if (!protocol.isMasterConnection()) {
           if (listener.isSecondaryHostFailReconnect()) {
-            // in case cluster DNS is currently pointing to a slave host
+            // in case cluster DNS is currently pointing to a replica host
             if (listener.getUrlParser().getHostAddresses().size() <= 1
                 && protocol.getHostAddress().equals(listener.getClusterHostAddress())) {
               listener.retrieveAllEndpointsAndSet(protocol);
@@ -220,7 +225,7 @@ public class AuroraProtocol extends MastersSlavesProtocol {
                   loopAddresses.remove(probableMasterHost);
                   AuroraProtocol.searchProbableMaster(listener, globalInfo, probableMasterHost);
                   if (listener.isMasterHostFailReconnect()
-                      && searchFilter.isFineIfFoundOnlySlave()) {
+                      && searchFilter.isFineIfFoundOnlyReplica()) {
                     return;
                   }
                 }
@@ -242,7 +247,7 @@ public class AuroraProtocol extends MastersSlavesProtocol {
         return;
       }
 
-      // in case master not found but slave is , and allowing master down
+      // in case master not found but replica is , and allowing master down
       if (loopAddresses.isEmpty()
           && (listener.isMasterHostFailReconnect()
               && listener.urlParser.getOptions().allowMasterDownConnection
@@ -250,14 +255,15 @@ public class AuroraProtocol extends MastersSlavesProtocol {
         return;
       }
 
-      // on connection and all slaves have been tested, use master if on
+      // on connection and all replicas have been tested, use master if on
       if (loopAddresses.isEmpty()
           && searchFilter.isInitialConnection()
           && !listener.isMasterHostFailReconnect()) {
         return;
       }
 
-      // if server has try to connect to all host, and there is remaining master or slave that fail
+      // if server has try to connect to all host, and there is remaining master or replica that
+      // fail
       // add all servers back to continue looping until maxConnectionTry is reached
       if (loopAddresses.isEmpty() && !searchFilter.isFailoverLoop() && maxConnectionTry > 0) {
         resetHostList(listener, loopAddresses);
@@ -335,7 +341,8 @@ public class AuroraProtocol extends MastersSlavesProtocol {
    */
   public static AuroraProtocol getNewProtocol(
       FailoverProxy proxy, final GlobalStateInfo globalInfo, UrlParser urlParser) {
-    AuroraProtocol newProtocol = new AuroraProtocol(urlParser, globalInfo, proxy.lock);
+    AuroraProtocol newProtocol =
+        new AuroraProtocol(urlParser, globalInfo, proxy.lock, proxy.traceCache);
     newProtocol.setProxy(proxy);
     return newProtocol;
   }
