@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,23 +52,29 @@
 
 package org.mariadb.jdbc.internal.protocol;
 
-import org.mariadb.jdbc.*;
-import org.mariadb.jdbc.internal.com.read.dao.*;
-import org.mariadb.jdbc.internal.com.send.parameters.*;
-import org.mariadb.jdbc.internal.failover.*;
-import org.mariadb.jdbc.internal.io.input.*;
-import org.mariadb.jdbc.internal.io.output.*;
-import org.mariadb.jdbc.internal.util.*;
-import org.mariadb.jdbc.internal.util.dao.*;
-import org.mariadb.jdbc.util.*;
-
-import java.io.*;
-import java.net.*;
-import java.nio.charset.*;
-import java.sql.*;
-import java.util.*;
-import java.util.concurrent.*;
-import java.util.concurrent.locks.*;
+import java.io.IOException;
+import java.io.InputStream;
+import java.net.Socket;
+import java.net.SocketException;
+import java.nio.charset.Charset;
+import java.sql.SQLException;
+import java.sql.SQLTimeoutException;
+import java.util.List;
+import java.util.TimeZone;
+import java.util.concurrent.FutureTask;
+import java.util.concurrent.locks.ReentrantLock;
+import org.mariadb.jdbc.HostAddress;
+import org.mariadb.jdbc.MariaDbConnection;
+import org.mariadb.jdbc.MariaDbStatement;
+import org.mariadb.jdbc.UrlParser;
+import org.mariadb.jdbc.internal.com.read.dao.Results;
+import org.mariadb.jdbc.internal.com.send.parameters.ParameterHolder;
+import org.mariadb.jdbc.internal.failover.FailoverProxy;
+import org.mariadb.jdbc.internal.io.input.PacketInputStream;
+import org.mariadb.jdbc.internal.util.ServerPrepareStatementCache;
+import org.mariadb.jdbc.internal.util.dao.ClientPrepareResult;
+import org.mariadb.jdbc.internal.util.dao.ServerPrepareResult;
+import org.mariadb.jdbc.util.Options;
 
 public interface Protocol {
 
@@ -166,8 +172,7 @@ public interface Protocol {
       boolean mustExecuteOnMaster,
       Results results,
       final ClientPrepareResult prepareResult,
-      final List<ParameterHolder[]> parametersList,
-      boolean hasLongData)
+      final List<ParameterHolder[]> parametersList)
       throws SQLException;
 
   void executeBatchStmt(boolean mustExecuteOnMaster, Results results, final List<String> queries)
@@ -185,8 +190,7 @@ public interface Protocol {
       ServerPrepareResult serverPrepareResult,
       Results results,
       String sql,
-      List<ParameterHolder[]> parameterList,
-      boolean hasLongData)
+      List<ParameterHolder[]> parameterList)
       throws SQLException;
 
   void getResult(Results results) throws SQLException;
@@ -269,7 +273,7 @@ public interface Protocol {
 
   void setHasWarnings(boolean hasWarnings);
 
-  ServerPrepareResult addPrepareInCache(String key, ServerPrepareResult serverPrepareResult);
+  ServerPrepareResult putInCache(String key, ServerPrepareResult serverPrepareResult);
 
   void readEofPacket() throws SQLException, IOException;
 
@@ -293,8 +297,6 @@ public interface Protocol {
 
   PacketInputStream getReader();
 
-  PacketOutputStream getWriter();
-
   boolean isEofDeprecated();
 
   int getAutoIncrementIncrement() throws SQLException;
