@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,26 +52,38 @@
 
 package org.mariadb.jdbc.internal.util;
 
-import org.mariadb.jdbc.*;
-import org.mariadb.jdbc.internal.com.send.parameters.*;
-import org.mariadb.jdbc.internal.failover.*;
-import org.mariadb.jdbc.internal.failover.impl.*;
-import org.mariadb.jdbc.internal.io.socket.*;
-import org.mariadb.jdbc.internal.logging.*;
-import org.mariadb.jdbc.internal.protocol.*;
-import org.mariadb.jdbc.internal.util.pool.*;
-import org.mariadb.jdbc.util.*;
-
-import javax.net.*;
-import java.io.*;
+import java.io.ByteArrayOutputStream;
+import java.io.IOException;
+import java.io.UnsupportedEncodingException;
+import java.lang.reflect.Constructor;
 import java.lang.reflect.Proxy;
-import java.lang.reflect.*;
-import java.net.*;
-import java.security.*;
-import java.sql.*;
-import java.util.*;
-import java.util.concurrent.locks.*;
-import java.util.regex.*;
+import java.net.Socket;
+import java.security.MessageDigest;
+import java.security.NoSuchAlgorithmException;
+import java.sql.Connection;
+import java.sql.SQLException;
+import java.util.Locale;
+import java.util.TimeZone;
+import java.util.concurrent.locks.ReentrantLock;
+import java.util.regex.Pattern;
+import javax.net.SocketFactory;
+import org.mariadb.jdbc.UrlParser;
+import org.mariadb.jdbc.internal.com.send.parameters.ParameterHolder;
+import org.mariadb.jdbc.internal.failover.FailoverProxy;
+import org.mariadb.jdbc.internal.failover.impl.AuroraListener;
+import org.mariadb.jdbc.internal.failover.impl.MastersFailoverListener;
+import org.mariadb.jdbc.internal.failover.impl.MastersReplicasListener;
+import org.mariadb.jdbc.internal.io.LruTraceCache;
+import org.mariadb.jdbc.internal.io.socket.SocketHandlerFunction;
+import org.mariadb.jdbc.internal.io.socket.SocketUtility;
+import org.mariadb.jdbc.internal.logging.ProtocolLoggingProxy;
+import org.mariadb.jdbc.internal.protocol.AuroraProtocol;
+import org.mariadb.jdbc.internal.protocol.MasterProtocol;
+import org.mariadb.jdbc.internal.protocol.MastersReplicasProtocol;
+import org.mariadb.jdbc.internal.protocol.Protocol;
+import org.mariadb.jdbc.internal.util.pool.GlobalStateInfo;
+import org.mariadb.jdbc.util.ConfigurableSocketFactory;
+import org.mariadb.jdbc.util.Options;
 
 @SuppressWarnings("Annotator")
 public class Utils {
@@ -121,6 +133,9 @@ public class Utils {
         if (socketFactoryClass != null) {
           Constructor<? extends SocketFactory> constructor = socketFactoryClass.getConstructor();
           socketFactory = constructor.newInstance();
+          if (ConfigurableSocketFactory.class.isInstance(socketFactory)) {
+            ((ConfigurableSocketFactory) socketFactory).setConfiguration(options, host);
+          }
           return socketFactory.createSocket();
         }
       } catch (Exception exp) {
@@ -274,7 +289,8 @@ public class Utils {
     }
 
     for (;
-        ((input[index] >= 'a' && input[index] <= 'z') || (input[index] >= 'A' && input[index] <= 'Z'))
+        ((input[index] >= 'a' && input[index] <= 'z')
+                || (input[index] >= 'A' && input[index] <= 'Z'))
             && index < input.length;
         index++) {
       sb.append(input[index]);
@@ -478,6 +494,8 @@ public class Utils {
       char car = charArray[i];
       if (lastChar == '\\' && !protocol.noBackslashEscapes()) {
         sqlBuffer.append(car);
+        // avoid considering escaped backslash as a futur escape character
+        lastChar = ' ';
         continue;
       }
 
@@ -542,6 +560,7 @@ public class Utils {
               escapeSequenceBuf.append(car);
               sqlBuffer.append(resolveEscapes(escapeSequenceBuf.toString(), protocol));
               escapeSequenceBuf.setLength(0);
+              lastChar = car;
               continue;
             }
           }
@@ -577,6 +596,8 @@ public class Utils {
   public static Protocol retrieveProxy(final UrlParser urlParser, final GlobalStateInfo globalInfo)
       throws SQLException {
     final ReentrantLock lock = new ReentrantLock();
+    final LruTraceCache traceCache =
+        urlParser.getOptions().enablePacketDebug ? new LruTraceCache() : null;
     Protocol protocol;
     switch (urlParser.getHaMode()) {
       case AURORA:
@@ -586,15 +607,17 @@ public class Utils {
                 Proxy.newProxyInstance(
                     AuroraProtocol.class.getClassLoader(),
                     new Class[] {Protocol.class},
-                    new FailoverProxy(new AuroraListener(urlParser, globalInfo), lock)));
+                    new FailoverProxy(
+                        new AuroraListener(urlParser, globalInfo), lock, traceCache)));
       case REPLICATION:
         return getProxyLoggingIfNeeded(
             urlParser,
             (Protocol)
                 Proxy.newProxyInstance(
-                    MastersSlavesProtocol.class.getClassLoader(),
+                    MastersReplicasProtocol.class.getClassLoader(),
                     new Class[] {Protocol.class},
-                    new FailoverProxy(new MastersSlavesListener(urlParser, globalInfo), lock)));
+                    new FailoverProxy(
+                        new MastersReplicasListener(urlParser, globalInfo), lock, traceCache)));
       case LOADBALANCE:
       case SEQUENTIAL:
         return getProxyLoggingIfNeeded(
@@ -603,10 +626,12 @@ public class Utils {
                 Proxy.newProxyInstance(
                     MasterProtocol.class.getClassLoader(),
                     new Class[] {Protocol.class},
-                    new FailoverProxy(new MastersFailoverListener(urlParser, globalInfo), lock)));
+                    new FailoverProxy(
+                        new MastersFailoverListener(urlParser, globalInfo), lock, traceCache)));
       default:
         protocol =
-            getProxyLoggingIfNeeded(urlParser, new MasterProtocol(urlParser, globalInfo, lock));
+            getProxyLoggingIfNeeded(
+                urlParser, new MasterProtocol(urlParser, globalInfo, lock, traceCache));
         protocol.connectWithoutProxy();
         return protocol;
     }
@@ -665,25 +690,17 @@ public class Utils {
   }
 
   /**
-   * Hexdump.
+   * Hexdump. Multiple byte arrays will be combined
    *
    * <p>String output example :
    *
    * <pre>{@code
-   * 7D 00 00 01 C5 00 00                                 }......            &lt;- first byte array
-   * 01 00 00 01 02 33 00 00  02 03 64 65 66 05 74 65     .....3....def.te   &lt;- second byte array
-   * 73 74 6A 0A 74 65 73 74  5F 62 61 74 63 68 0A 74     stj.test_batch.t
-   * 65 73 74 5F 62 61 74 63  68 02 69 64 02 69 64 0C     est_batch.id.id.
-   * 3F 00 0B 00 00 00 03 03  42 00 00 00 37 00 00 03     ?.......B...7...
-   * 03 64 65 66 05 74 65 73  74 6A 0A 74 65 73 74 5F     .def.testj.test_
-   * 62 61 74 63 68 0A 74 65  73 74 5F 62 61 74 63 68     batch.test_batch
-   * 04 74 65 73 74 04 74 65  73 74 0C 21 00 1E 00 00     .test.test.!....
-   * 00 FD 00 00 00 00 00 05  00 00 04 FE 00 00 22 00     ..............".
-   * 06 00 00 05 01 31 03 61  61 61 06 00 00 06 01 32     .....1.aaa.....2
-   * 03 62 62 62 06 00 00 07  01 33 03 63 63 63 06 00     .bbb.....3.ccc..
-   * 00 08 01 34 03 61 61 61  06 00 00 09 01 35 03 62     ...4.aaa.....5.b
-   * 62 62 06 00 00 0A 01 36  03 63 63 63 05 00 00 0B     bb.....6.ccc....
-   * FE 00 00 22 00                                       ...".
+   * +--------------------------------------------------+
+   * |  0  1  2  3  4  5  6  7   8  9  a  b  c  d  e  f |
+   * +--------------------------------------------------+------------------+
+   * | 11 00 00 02 00 00 00 02  40 00 00 00 08 01 06 05 | ........@....... |
+   * | 74 65 73 74 6A                                   | testj            |
+   * +--------------------------------------------------+------------------+
    * }</pre>
    *
    * @param maxQuerySizeToLog max log size
@@ -711,17 +728,28 @@ public class Utils {
         return outputBuilder.toString();
 
       default:
-        StringBuilder sb = new StringBuilder();
-        sb.append("\n");
-        byte[] arr;
-        for (int i = 0; i < byteArr.length - 1; i++) {
-          arr = byteArr[i];
-          writeHex(arr, 0, arr.length, sb);
+        ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
+        try {
+          outputStream.write(byteArr[0]);
+          outputStream.write(byteArr[1], offset, Math.min(length, byteArr[1].length));
+          for (int i = 2; i < byteArr.length; i++) {
+            outputStream.write(byteArr[i]);
+          }
+        } catch (IOException ioe) {
+          // eat
         }
-        arr = byteArr[byteArr.length - 1];
-        int dataLength2 = Math.min(maxQuerySizeToLog, Math.min(arr.length - offset, length));
-        writeHex(arr, offset, dataLength2, sb);
-        return sb.toString();
+
+        byte[] concat = outputStream.toByteArray();
+        if (concat.length <= offset) {
+          return "";
+        }
+
+        int stlength = Math.min(maxQuerySizeToLog, outputStream.size());
+
+        StringBuilder out = new StringBuilder(stlength * 3 + 80);
+        out.append("\n");
+        writeHex(outputStream.toByteArray(), 0, outputStream.size(), out);
+        return out.toString();
     }
   }
 
@@ -731,10 +759,17 @@ public class Utils {
    * <p>String output example :
    *
    * <pre>{@code
-   * 38 00 00 00 03 63 72 65  61 74 65 20 74 61 62 6C     8....create tabl
-   * 65 20 42 6C 6F 62 54 65  73 74 63 6C 6F 62 74 65     e BlobTestclobte
-   * 73 74 32 20 28 73 74 72  6D 20 74 65 78 74 29 20     st2 (strm text)
-   * 43 48 41 52 53 45 54 20  75 74 66 38                 CHARSET utf8
+   * +--------------------------------------------------+
+   * |  0  1  2  3  4  5  6  7   8  9  a  b  c  d  e  f |
+   * +--------------------------------------------------+------------------+
+   * | 5F 00 00 00 03 73 65 74  20 61 75 74 6F 63 6F 6D | _....set autocom |
+   * | 6D 69 74 3D 31 2C 20 73  65 73 73 69 6F 6E 5F 74 | mit=1, session_t |
+   * | 72 61 63 6B 5F 73 63 68  65 6D 61 3D 31 2C 20 73 | rack_schema=1, s |
+   * | 71 6C 5F 6D 6F 64 65 20  3D 20 63 6F 6E 63 61 74 | ql_mode = concat |
+   * | 28 40 40 73 71 6C 5F 6D  6F 64 65 2C 27 2C 53 54 | (@@sql_mode,',ST |
+   * | 52 49 43 54 5F 54 52 41  4E 53 5F 54 41 42 4C 45 | RICT_TRANS_TABLE |
+   * | 53 27 29                                         | S')              |
+   * +--------------------------------------------------+------------------+
    * }</pre>
    *
    * @param bytes byte array
@@ -755,6 +790,11 @@ public class Utils {
     int pos = offset;
     int posHexa = 0;
 
+    outputBuilder.append(
+        "+--------------------------------------------------+\n"
+            + "|  0  1  2  3  4  5  6  7   8  9  a  b  c  d  e  f |\n"
+            + "+--------------------------------------------------+------------------+\n| ");
+
     while (pos < dataLength + offset) {
       int byteValue = bytes[pos] & 0xFF;
       outputBuilder
@@ -768,7 +808,8 @@ public class Utils {
         outputBuilder.append(" ");
       }
       if (posHexa == 16) {
-        outputBuilder.append("    ").append(hexaValue).append("\n");
+        outputBuilder.append("| ").append(hexaValue).append(" |\n");
+        if (pos + 1 != dataLength + offset) outputBuilder.append("| ");
         posHexa = 0;
       }
       pos++;
@@ -787,8 +828,14 @@ public class Utils {
         outputBuilder.append("   ");
       }
 
-      outputBuilder.append("    ").append(hexaValue, 0, posHexa).append("\n");
+      for (; posHexa < 16; posHexa++) {
+        hexaValue[posHexa] = ' ';
+      }
+
+      outputBuilder.append("| ").append(hexaValue).append(" |\n");
     }
+    outputBuilder.append(
+        "+--------------------------------------------------+------------------+\n");
   }
 
   private static String getHex(final byte[] raw) {
@@ -803,28 +850,6 @@ public class Utils {
     return (bytes != null) ? getHex(bytes) : "";
   }
 
-  /**
-   * Convert int value to hexadecimal String.
-   *
-   * @param value value to transform
-   * @return Hexadecimal String value of integer.
-   */
-  public static String intToHexString(final int value) {
-    final StringBuilder hex = new StringBuilder(8);
-    int offset = 24;
-    byte b;
-    boolean nullEnd = false;
-    while (offset >= 0) {
-      b = (byte) (value >> offset);
-      offset -= 8;
-      if (b != 0 || nullEnd) {
-        nullEnd = true;
-        hex.append(hexArray[(b & 0xF0) >> 4]).append(hexArray[(b & 0x0F)]);
-      }
-    }
-    return hex.toString();
-  }
-
   /**
    * Parse the option "sessionVariable" to ensure having no injection. semi-column not in string
    * will be replaced by comma.
@@ -983,7 +1008,7 @@ public class Utils {
       String sql, ParameterHolder[] parameters, String fileName) {
     Pattern pattern =
         Pattern.compile(
-            "^(\\s*\\/\\*([^\\*]|\\*[^\\/])*\\*\\/)*\\s*LOAD\\s+DATA\\s+((LOW_PRIORITY|CONCURRENT)\\s+)?LOCAL\\s+INFILE\\s+'"
+            "^(\\s*\\/\\*([^\\*]|\\*[^\\/])*\\*\\/)*\\s*LOAD\\s+(DATA|XML)\\s+((LOW_PRIORITY|CONCURRENT)\\s+)?LOCAL\\s+INFILE\\s+'"
                 + fileName
                 + "'",
             Pattern.CASE_INSENSITIVE);
@@ -994,7 +1019,7 @@ public class Utils {
     if (parameters != null) {
       pattern =
           Pattern.compile(
-              "^(\\s*\\/\\*([^\\*]|\\*[^\\/])*\\*\\/)*\\s*LOAD\\s+DATA\\s+((LOW_PRIORITY|CONCURRENT)\\s+)?LOCAL\\s+INFILE\\s+\\?",
+              "^(\\s*\\/\\*([^\\*]|\\*[^\\/])*\\*\\/)*\\s*LOAD\\s+(DATA|XML)\\s+((LOW_PRIORITY|CONCURRENT)\\s+)?LOCAL\\s+INFILE\\s+\\?",
               Pattern.CASE_INSENSITIVE);
       if (pattern.matcher(sql).find() && parameters.length > 0) {
         return parameters[0].toString().toLowerCase().equals("'" + fileName.toLowerCase() + "'");
