@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -55,5 +55,5 @@ package org.mariadb.jdbc.internal.util.constant;
 public class ParameterConstant {
 
   public static final String TYPE_MASTER = "master";
-  public static final String TYPE_SLAVE = "slave";
+  public static final String TYPE_REPLICA = "replica";
 }
