@@ -74,7 +74,7 @@ public class DatatypeTest extends BaseTest {
 
   @BeforeClass()
   public static void initClass() throws SQLException {
-    afterClass();
+    drop();
     try (PreparedStatement prep = sharedConnection.prepareStatement("SELECT ?")) {
       prep.setInt(1, 1000);
       prep.execute(); // will send a query "SELECT 1000"
@@ -156,7 +156,7 @@ public class DatatypeTest extends BaseTest {
   }
 
   @AfterClass
-  public static void afterClass() throws SQLException {
+  public static void drop() throws SQLException {
     try (Statement stmt = sharedConnection.createStatement()) {
       stmt.execute("DROP TABLE IF EXISTS Driverstreamtest");
       stmt.execute("DROP TABLE IF EXISTS Driverstreamtest2");
@@ -1074,14 +1074,18 @@ public class DatatypeTest extends BaseTest {
         preparedStatement.execute();
         fail("must have fail");
       } catch (SQLException sqle) {
-        assertTrue(sqle.getMessage().contains("Incorrect string value"));
+        assertTrue(
+            sqle.getMessage().contains("Incorrect string value")
+                || sqle.getMessage().contains("Conversion from"));
       }
 
       try {
         preparedStatement.setBytes(1, str.getBytes(StandardCharsets.UTF_8));
         preparedStatement.execute();
       } catch (SQLException sqle) {
-        assertTrue(sqle.getMessage().contains("Incorrect string value"));
+        assertTrue(
+            sqle.getMessage().contains("Incorrect string value")
+                || sqle.getMessage().contains("Conversion from"));
       }
 
       ByteArrayInputStream bais = new ByteArrayInputStream(str.getBytes(StandardCharsets.UTF_8));
