@@ -64,6 +64,7 @@ import java.util.concurrent.*;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicReference;
+import org.junit.AfterClass;
 import org.junit.Assume;
 import org.junit.BeforeClass;
 import org.junit.Test;
@@ -81,17 +82,23 @@ public class ExecuteBatchTest extends BaseTest {
     oneHundredLengthString = new String(chars);
   }
 
-  /**
-   * Create test tables.
-   *
-   * @throws SQLException if connection error occur
-   */
   @BeforeClass()
   public static void initClass() throws SQLException {
-    createTable(
-        "ExecuteBatchTest",
-        "id int not null primary key auto_increment, test varchar(100) , test2 int");
-    createTable("ExecuteBatchUseBatchMultiSend", "test varchar(100)");
+    drop();
+    try (Statement stmt = sharedConnection.createStatement()) {
+      stmt.execute(
+          "CREATE TABLE ExecuteBatchTest(id int not null primary key auto_increment, test varchar(100) , test2 int)");
+      stmt.execute("CREATE TABLE ExecuteBatchUseBatchMultiSend(test varchar(100))");
+      stmt.execute("FLUSH TABLES");
+    }
+  }
+
+  @AfterClass
+  public static void drop() throws SQLException {
+    try (Statement stmt = sharedConnection.createStatement()) {
+      stmt.execute("DROP TABLE IF EXISTS ExecuteBatchTest");
+      stmt.execute("DROP TABLE IF EXISTS ExecuteBatchUseBatchMultiSend");
+    }
   }
 
   /**
@@ -171,12 +178,11 @@ public class ExecuteBatchTest extends BaseTest {
   @Test
   public void serverBulk1mTest() throws SQLException {
     Assume.assumeTrue(checkMaxAllowedPacketMore8m("serverBulk1mTest"));
-    Assume.assumeTrue(runLongTest);
+    //    Assume.assumeTrue(runLongTest);
     Assume.assumeFalse(sharedIsAurora());
     Assume.assumeTrue(isMariadbServer());
-
-    sharedConnection.createStatement().execute("TRUNCATE TABLE ExecuteBatchTest");
-
+    Statement stmt = sharedConnection.createStatement();
+    stmt.execute("TRUNCATE TABLE ExecuteBatchTest");
     try (Connection connection =
         setConnection(
             "&useBulkStmts=true&useComMulti=false&useBatchMultiSend=true&profileSql="
@@ -289,6 +295,9 @@ public class ExecuteBatchTest extends BaseTest {
       boolean additionnalParameter,
       boolean sendUnique)
       throws SQLException {
+    Statement stmt = connection.createStatement();
+    stmt.execute("START TRANSACTION");
+
     for (int i = 0; i < batchNumber; i++) {
       preparedStatement.setString(1, oneHundredLengthString);
       preparedStatement.setInt(2, i);
@@ -310,8 +319,7 @@ public class ExecuteBatchTest extends BaseTest {
     }
 
     // check that connection is OK and results are well inserted
-    ResultSet resultSet =
-        connection.createStatement().executeQuery("SELECT * FROM ExecuteBatchTest");
+    ResultSet resultSet = stmt.executeQuery("SELECT * FROM ExecuteBatchTest");
     for (int i = 0; i < batchNumber; i++) {
       assertTrue(resultSet.next());
       if (sendUnique
@@ -356,52 +364,55 @@ public class ExecuteBatchTest extends BaseTest {
   @Test
   public void ensureBulkSchedulerMaxPoolSizeRejection() throws Throwable {
     Assume.assumeFalse(sharedIsAurora() || sharedOptions().profileSql);
-    System.out.println(getProtocolFromConnection(sharedConnection).getHostAddress());
 
-    Statement statement = sharedConnection.createStatement();
-    ResultSet resultSet = statement.executeQuery("SELECT @@max_connections");
+    Statement stmt = sharedConnection.createStatement();
+    ResultSet resultSet = stmt.executeQuery("SELECT @@max_connections");
     assertTrue(resultSet.next());
     int maxConnection = resultSet.getInt(1);
     int limit = Math.min(1, Math.min(200, maxConnection - 10));
-    System.out.println("limit:" + limit);
-    for (int i = 0; i < limit; i++) {
-      createTable("multipleSimultaneousBatch_" + i, "a INT NOT NULL");
-    }
+    try {
+      for (int i = 0; i < limit; i++) {
+        stmt.execute("CREATE TABLE multipleSimultaneousBatch_" + i + "(a INT NOT NULL)");
+      }
 
-    AtomicInteger counter = new AtomicInteger();
-    ExecutorService exec = Executors.newFixedThreadPool(limit + 50);
-    for (int i = 0; i < limit; i++) {
-      exec.execute(
-          () -> {
-            try (Connection connection = setConnection()) {
-              connection.setAutoCommit(false);
-              Statement stmt = connection.createStatement();
-              int connectionCounter = counter.getAndIncrement();
-              for (int j = 0; j < 1024; j++) {
-                stmt.addBatch(
-                    "INSERT INTO multipleSimultaneousBatch_"
-                        + connectionCounter
-                        + "(a) VALUES ("
-                        + j
-                        + ")");
+      AtomicInteger counter = new AtomicInteger();
+      ExecutorService exec = Executors.newFixedThreadPool(limit + 50);
+      for (int i = 0; i < limit; i++) {
+        exec.execute(
+            () -> {
+              try (Connection connection = setConnection()) {
+                connection.setAutoCommit(false);
+                Statement st = connection.createStatement();
+                int connectionCounter = counter.getAndIncrement();
+                for (int j = 0; j < 1024; j++) {
+                  st.addBatch(
+                      "INSERT INTO multipleSimultaneousBatch_"
+                          + connectionCounter
+                          + "(a) VALUES ("
+                          + j
+                          + ")");
+                }
+                st.executeBatch();
+                connection.commit();
+              } catch (Throwable e) {
+                e.printStackTrace();
               }
-              stmt.executeBatch();
-              connection.commit();
-            } catch (Throwable e) {
-              e.printStackTrace();
-            }
-          });
-    }
+            });
+      }
 
-    exec.shutdown();
-    exec.awaitTermination(150, TimeUnit.SECONDS);
+      exec.shutdown();
+      exec.awaitTermination(150, TimeUnit.SECONDS);
 
-    // check results
-    Statement stmt = sharedConnection.createStatement();
-    for (int i = 0; i < limit; i++) {
-      ResultSet rs = stmt.executeQuery("SELECT count(*) from multipleSimultaneousBatch_" + i);
-      assertTrue(rs.next());
-      assertEquals(1024, rs.getInt(1));
+      // check results
+      for (int i = 0; i < limit; i++) {
+        ResultSet rs = stmt.executeQuery("SELECT count(*) from multipleSimultaneousBatch_" + i);
+        assertTrue(rs.next());
+        assertEquals(1024, rs.getInt(1));
+      }
+    } finally {
+      for (int i = 0; i < limit; i++) {
+        stmt.execute("DROP TABLE multipleSimultaneousBatch_" + i);
+      }
     }
   }
 
