@@ -88,7 +88,8 @@ public class PooledConnectionTest extends BaseTest {
 
   @Test(expected = SQLException.class)
   public void testPooledConnectionException() throws Exception {
-    Assume.assumeTrue(System.getenv("SKYSQL") == null && System.getenv("SKYSQL_HA") == null);
+    Assume.assumeTrue(
+        !"skysql".equals(System.getenv("srv")) && !"skysql-ha".equals(System.getenv("srv")));
 
     ConnectionPoolDataSource ds =
         new MariaDbDataSource(hostname != null ? hostname : "localhost", port, database);
