@@ -67,6 +67,7 @@ public class UpdateResultSetTest extends BaseTest {
 
   @BeforeClass()
   public static void initClass() throws SQLException {
+    dropTables();
     try (Statement stmt = sharedConnection.createStatement()) {
       stmt.execute("CREATE TABLE testnoprimarykey(`id` INT NOT NULL,`t1` VARCHAR(50) NOT NULL)");
       stmt.execute(
@@ -132,7 +133,7 @@ public class UpdateResultSetTest extends BaseTest {
   }
 
   @AfterClass
-  public static void afterClass() throws SQLException {
+  public static void dropTables() throws SQLException {
     try (Statement stmt = sharedConnection.createStatement()) {
       stmt.executeQuery("DROP TABLE IF EXISTS `testDefaultUUID`");
       stmt.execute("DROP TABLE IF EXISTS testnoprimarykey");
@@ -177,7 +178,7 @@ public class UpdateResultSetTest extends BaseTest {
       try {
         rs.updateString(1, "1");
         fail();
-      } catch (SQLException sqle) {
+      } catch (SQLFeatureNotSupportedException sqle) {
         assertEquals(
             "ResultSet cannot be updated. Table "
                 + "`"
@@ -198,7 +199,7 @@ public class UpdateResultSetTest extends BaseTest {
       try {
         rs.updateString(1, "1");
         fail();
-      } catch (SQLException sqle) {
+      } catch (SQLFeatureNotSupportedException sqle) {
         assertTrue(
             sqle.getMessage(),
             sqle.getMessage()
@@ -224,7 +225,7 @@ public class UpdateResultSetTest extends BaseTest {
       try {
         rs.updateString("t1", "new value");
         fail("must have failed since there is different tables");
-      } catch (SQLException sqle) {
+      } catch (SQLFeatureNotSupportedException sqle) {
         assertTrue(
             sqle.getMessage(),
             sqle.getMessage()
@@ -250,7 +251,7 @@ public class UpdateResultSetTest extends BaseTest {
       try {
         rs.updateString("t1", "new value");
         fail("must have failed since there is a field without database");
-      } catch (SQLException sqle) {
+      } catch (SQLFeatureNotSupportedException sqle) {
         assertTrue(
             sqle.getMessage(),
             sqle.getMessage()
@@ -289,7 +290,7 @@ public class UpdateResultSetTest extends BaseTest {
         try {
           rs.updateString("t1", "new value");
           fail("must have failed since there is different database");
-        } catch (SQLException sqle) {
+        } catch (SQLFeatureNotSupportedException sqle) {
           assertTrue(
               sqle.getMessage(),
               sqle.getMessage().contains("The result-set contains more than one database"));
