@@ -76,14 +76,18 @@ public class MonoServerFailoverTest extends BaseMonoServer {
   /** Initialisation. */
   @Before
   public void init() {
-    Assume.assumeTrue(initialUrl != null && System.getenv("SKYSQL") == null);
+    Assume.assumeTrue(
+        initialUrl != null
+            && !"skysql".equals(System.getenv("srv"))
+            && !"skysql-ha".equals(System.getenv("srv")));
     defaultUrl = initialUrl;
     currentType = HaMode.NONE;
   }
 
   @Test
   public void checkClosedConnectionAfterFailover() throws Throwable {
-    try (Connection connection = getNewConnection("&retriesAllDown=6", true)) {
+    try (Connection connection =
+        getNewConnection("&retriesAllDown=6&allowPublicKeyRetrieval", true)) {
 
       Statement st = connection.createStatement();
       int masterServerId = getServerId(connection);
@@ -132,7 +136,8 @@ public class MonoServerFailoverTest extends BaseMonoServer {
 
   @Test
   public void checkAutoReconnectDeconnection() throws Throwable {
-    try (Connection connection = getNewConnection("&retriesAllDown=6", true)) {
+    try (Connection connection =
+        getNewConnection("&retriesAllDown=6&allowPublicKeyRetrieval", true)) {
 
       Statement st = connection.createStatement();
       int masterServerId = getServerId(connection);
@@ -163,7 +168,10 @@ public class MonoServerFailoverTest extends BaseMonoServer {
    */
   @Test
   public void isValidConnectionThatIsKilledExternally() throws Throwable {
-    Assume.assumeTrue(System.getenv("MAXSCALE_VERSION") == null && System.getenv("SKYSQL") == null);
+    Assume.assumeTrue(
+        !"skysql".equals(System.getenv("srv"))
+            && !"skysql-ha".equals(System.getenv("srv"))
+            && !"maxscale".equals(System.getenv("srv")));
     try (Connection connection = getNewConnection()) {
       connection.setCatalog("mysql");
       Protocol protocol = getProtocolFromConnection(connection);
@@ -183,7 +191,7 @@ public class MonoServerFailoverTest extends BaseMonoServer {
       Statement stmt = connection.createStatement();
       stmt.execute("drop table  if exists failt1");
       stmt.execute("create table failt1 (id int not null primary key auto_increment, tt int)");
-
+      stmt.execute("FLUSH TABLES");
       PreparedStatement preparedStatement =
           connection.prepareStatement("insert into failt1(id, tt) values (?,?)");
 
