@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,10 +52,11 @@
 
 package org.mariadb.jdbc.failover;
 
-import org.junit.*;
-import org.mariadb.jdbc.*;
-
-import java.sql.*;
+import java.sql.Connection;
+import java.sql.Statement;
+import org.junit.Assert;
+import org.junit.Test;
+import org.mariadb.jdbc.BaseTest;
 
 public class OldFailoverTest extends BaseTest {
 
